diff lisp/calc/calc-help.el @ 90737:95d0cdf160ea

Merge from emacs--devo--0 Patches applied: * emacs--devo--0 (patch 586-614) - Update from CVS - Update from erc--emacs--22 - Merge from gnus--rel--5.10 - Merge from erc--main--0 - Make byte compiler correctly write circular constants * gnus--rel--5.10 (patch 186-196) - Update from CVS - Merge from emacs--devo--0 Revision: emacs@sv.gnu.org/emacs--unicode--0--patch-162
author Miles Bader <miles@gnu.org>
date Fri, 26 Jan 2007 06:16:11 +0000
parents c5406394f567 7a3f13e2dd57
children c0409ee15cee
line wrap: on
line diff
--- a/lisp/calc/calc-help.el	Fri Jan 26 02:30:28 2007 +0000
+++ b/lisp/calc/calc-help.el	Fri Jan 26 06:16:11 2007 +0000
@@ -1,7 +1,7 @@
 ;;; calc-help.el --- help display functions for Calc,
 
 ;; Copyright (C) 1990, 1991, 1992, 1993, 2001, 2002, 2003, 2004,
 ;;   2005, 2006  Free Software Foundation, Inc.
 
 ;; Author: David Gillespie <daveg@synaptics.com>
 ;; Maintainer: Jay Belanger <belanger@truman.edu>
@@ -414,7 +414,7 @@
     (princ (format "GNU Emacs Calculator version %s.\n"
 		   calc-version))
     (princ "  By Dave Gillespie.\n")
-    (princ "  Copyright (C) 2006 Free Software Foundation, Inc.\n\n")
+    (princ "  Copyright (C) 2007 Free Software Foundation, Inc.\n\n")
     (princ "Type `h s' for a more detailed summary.\n")
     (princ "Or type `h i' to read the full Calc manual on-line.\n\n")
     (princ "Basic keys:\n")
@@ -1,7 +1,7 @@
 
 ;; Copyright (C) 1990, 1991, 1992, 1993, 2001, 2002, 2003, 2004,
-;;   2005, 2006  Free Software Foundation, Inc.
+;;   2005, 2006, 2007  Free Software Foundation, Inc.
 
 ;; Author: David Gillespie <daveg@synaptics.com>